package com.muyu.marketing.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.ActivityTeamInfo;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;

/**
 * 活动suk回显模型
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class ActivityTeamDetailModel extends BaseEntity {

    /**
     * 活动ID
     */
    public Long id;
    /**
     * 拼团名称
     */
    private String name;
    /**
     * 商品ID
     */
    private Long productId;
    /**
     * 商品活动图
     */
    private String productImage;
    /**
     * 活动简介
     */
    private String introduction;
    /**
     * 单位
     */

    private String unit;
    /**
     * 轮播图
     */

    private String imageList;
    /**
     * 活动结束时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private Date endTime;
    /**
     * 活动排序
     */
    private Long sort;
    /**
     * 商品SkU集合
     */
    private List<ActivityTeamProductSkuDetailModel> productSkuDetailModelList;
    /**
     * 活动详情
     */
    private String content;
    /**
     * 活动状态
     */
    private String status;
    /**
     * 策略类型
     */
    private String strategyType;
    /**
     * 策略ID
     */
    private Long strategyId;


    public static ActivityTeamDetailModel findActivity(ActivityTeamInfo activityTeamInfo) {
        return ActivityTeamDetailModel.builder()
                .id(activityTeamInfo.getId())
                .name(activityTeamInfo.getName())
                .productId(activityTeamInfo.getProductId())
                .productImage(activityTeamInfo.getProductImage())
                .introduction(activityTeamInfo.getIntroduction())
                .unit(activityTeamInfo.getUnit())
                .imageList(activityTeamInfo.getImageList())
                .endTime(activityTeamInfo.getEndTime())
                .sort(activityTeamInfo.getSort())
                .content(activityTeamInfo.getContent())
                .status(activityTeamInfo.getStatus())
                .strategyType(activityTeamInfo.getStrategyType())
                .strategyId(activityTeamInfo.getStrategyId())
                .build();
    }


}
