package com.muyu.marketing.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.req.ActivityTeamProjectSkuInfoUpdReq;
import com.muyu.marketing.domain.req.ActivityTeamUpdReq;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;

/**
 * 活动修改模型
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class ActivityTeamUpdModel extends BaseEntity {

    /**
     * 活动ID
     */
    private Long id;
    /**
     * 拼团名称
     */
    private String name;
    /**
     * 商品ID
     */
    private Long productId;
    /**
     * 商品活动图
     */
    private String productImage;
    /**
     * 活动简介
     */
    private String introduction;
    /**
     * 单位
     */

    private String unit;
    /**
     * 轮播图
     */

    private String imageList;
    /**
     * 活动结束时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private Date endTime;
    /**
     * 活动排序
     */
    private Long sort;
    /**
     * 商品SkU集合
     */
    private List<ActivityTeamProjectSkuInfoUpdModel> teamProjectSkuInfoUpdModelList;
    /**
     * 活动详情
     */
    private String content;
    /**
     * 活动状态
     */
    private String status;
    /**
     * 策略类型
     */
    private String strategyType;
    /**
     * 策略ID
     */
    private Long strategyId;

    public static ActivityTeamUpdModel updActivityTeamModel(ActivityTeamUpdReq activityTeamUpdReq) {
        return ActivityTeamUpdModel.builder()
                .id(activityTeamUpdReq.getId())
                .name(activityTeamUpdReq.getName())
                .productId(activityTeamUpdReq.getProductId())
                .productImage(activityTeamUpdReq.getProductImage())
                .introduction(activityTeamUpdReq.getIntroduction())
                .unit(activityTeamUpdReq.getUnit())
                .imageList(activityTeamUpdReq.getImageList())
                .endTime(activityTeamUpdReq.getEndTime())
                .sort(activityTeamUpdReq.getSort())
                .content(activityTeamUpdReq.getContent())
                .status(activityTeamUpdReq.getStatus())
                .strategyType(activityTeamUpdReq.getStrategyType())
                .strategyId(activityTeamUpdReq.getStrategyId())
                .teamProjectSkuInfoUpdModelList(activityTeamUpdReq.getTeamProjectSkuInfoUpdReqList().stream().map(ActivityTeamProjectSkuInfoUpdModel::updSkuModel).toList())
                .build();
    }


}
